@@ -43,13 +43,15 @@ class searchBySlug:
 		if self.misoSoup.find('div', attrs={'class': "noarticletext"}):
 			dataAbstract.append("Unable to find the requested query: please check the spelling of the slug")
 		else:
-			if self.misoSoup.find(class_="infobox_v2"):
+			if self.misoSoup.find(class_="infobox_v3"):
+				info_class_name = "infobox_v3"
+			elif self.misoSoup.find(class_="infobox_v2"):
 				info_class_name = "infobox_v2"
 			else:
 				info_class_name = "infobox"
 
-			tag = self.misoSoup.find(class_=info_class_name).findNext('p')
-
+			tag = self.misoSoup.find(class_=info_class_name).find_next_sibling('p')
+	
 			# Thanks salmanwahed
 			# https://stackoverflow.com/questions/34585206/beautiful-soup-find-all-p-until-form
 			for i in range(limit):
@@ -70,7 +72,9 @@ class searchBySlug:
 		if self.misoSoup.find('div', attrs={'class': "noarticletext"}):
 			value_label.append("Unable to find the requested query: please check the spelling of the slug")
 		else:
-			if self.misoSoup.find(class_="infobox_v2"):
+			if self.misoSoup.find(class_="infobox_v3"):
+				info_class_name = "infobox_v3"
+			elif self.misoSoup.find(class_="infobox_v2"):
 				info_class_name = "infobox_v2"
 			else:
 				info_class_name = "infobox"
@@ -85,10 +89,10 @@ class searchBySlug:
 						row_label = tr.find('th').text
 						
 					if row_label == label:
-						if tr.find('td').find('a', attrs={'class': None}):
-							row_value = tr.find('td').find('a', attrs={'class': None}).text
-						else:
+						if tr.find('td').text:
 							row_value = tr.find('td').text
+						else:
+							row_value = tr.find('td').find('a', attrs={'class': None}).text
 
 						row_value = row_value.replace(u'\xa0', u' ').replace(u'\n', u'')
 						value_label.append(row_value)
@@ -155,12 +159,19 @@ class searchBySlug:
 		if self.misoSoup.find('div', attrs={'class': "noarticletext"}):
 			content.append("Unable to find the requested query: please check the spelling of the slug")
 		else:
-			all_li = self.misoSoup.find(class_="toctitle").findNext('ul')
+			if self.misoSoup.find(class_="toctitle"):
+				all_li = self.misoSoup.find(class_="toctitle").findNext('ul')
+				class_name_content = "toctext"
+			else:
+				all_li = self.misoSoup.find(class_="sidebar-toc-header").findNext('ul')
+				class_name_content = "sidebar-toc-text"
+
 			for li in all_li:
 				if not li.find('a') == -1:
-					li_value = li.find('a').find(class_="toctext").text
+					li_value = li.find('a').find(class_=class_name_content).text
 					
 					if not subcontents:
+						li_value = li_value.replace(u'\xa0', u' ').replace(u'\n', u'')
 						content.append(li_value)
 					else:
 						if li.find('ul'):
@@ -168,7 +179,8 @@ class searchBySlug:
 							list_li = []
 							for li_of_ul in all_li_of_ul:
 								if not li_of_ul.find('a') == -1:
-									li_of_ul = li_of_ul.find('a').find(class_="toctext").text
+									li_of_ul = li_of_ul.find('a').find(class_=class_name_content).text
+									li_of_ul = li_of_ul.replace(u'\xa0', u' ').replace(u'\n', u'')
 									list_li.append(li_of_ul)
 								
 								content[li_value] = list_li
